<?php
require_once( 'includes/customizer.php' );

add_theme_support( 'post-thumbnails' ); 

/**
 * Custom Functions
 */

function set_page_header() {
	$thumb_id = get_post_thumbnail_id();
	$thumb_url_array = wp_get_attachment_image_src($thumb_id, true);
	$thumb_url = $thumb_url_array[0];

	if ( !$thumb_url ) {
		return get_theme_mod( "perseverance_content_header" );
	} else {
		return 'section-image';
	}
}

function set_page_bgimg() {
	$thumb_id = get_post_thumbnail_id();
	$thumb_url_array = wp_get_attachment_image_src($thumb_id, true);
	$thumb_url = $thumb_url_array[0];


	if ( $thumb_url ) {
		return 'style="background-image: url(' . $thumb_url . '); color: white !important;"';
	}
}

function set_page_headerpad() {
	$custom_pad = get_theme_mod( "perseverance_header_padding" );

	if ( !$custom_pad ) {
		$custom_pad = 0;
	}
	
	return 'style="padding-top: ' . $custom_pad . ' !important; padding-bottom: ' . $custom_pad . ' !important;"';
}

function set_header_bottom_pad() {
	if ( get_theme_mod( "perseverance_below_header_pad" ) ) {
		return " mb-0";
	} else {
		return " mb-3";
	}
}

/**
 * Return container type based on user preference.
 */
function set_theme_container() {
	return ( get_theme_mod( "perseverance_theme_container" ) ? 'container-fluid' : 'container' );
}

/**
 * Return fold jumbotron class
 */
function set_fold_classname() {
	return ( get_theme_mod( "perseverance_homepage_fold_img" ) == '' ? 'section-no-image' : 'section-image' );
}

function get_fold_image() {
	if ( get_theme_mod( "perseverance_homepage_fold_img" ) == '/assets/images/dallas.jpg' ) {
		return 'style="background-image: url('.get_template_directory_uri().get_theme_mod( "perseverance_homepage_fold_img" ).');"';
	} else if ( get_theme_mod( "perseverance_homepage_fold_img" ) != '' ) {
		return 'style="background-image: url('.get_theme_mod( "perseverance_homepage_fold_img" ).');"';
	}
}

/**
 * Return lower jumbotron class
 */
function set_lower_classname() {
	return ( get_theme_mod( "perseverance_homepage_lower_img" ) == '' ? 'section-no-image' : 'section-image' );
}

function get_lower_image() {
	if ( get_theme_mod( "perseverance_homepage_lower_img" ) == '/assets/images/dallas2.jpg' ) {
		return 'style="background-image: url('.get_template_directory_uri().get_theme_mod( "perseverance_homepage_lower_img" ).');"';
	} else if ( get_theme_mod( "perseverance_homepage_lower_img" ) != '' ) {
		return 'style="background-image: url('.get_theme_mod( "perseverance_homepage_lower_img" ).');"';
	}
}

/**
 * Return featured category
 */
function get_featured_category() {
  return ( get_theme_mod( "perseverance_homepage_featured" ) ? 'featured' : get_theme_mod( "perseverance_homepage_featured" ) );
}

/**
 * Return featured posts length
 */
function get_featured_length() {
	return get_theme_mod( "perseverance_homepage_featlength" );
  }

/**
 * Filter the excerpt length to 20 words.
 *
 * @param int $length Excerpt length.
 * @return int (Maybe) modified excerpt length.
 * Credit: https://developer.wordpress.org/reference/functions/the_excerpt/
 */
function custom_excerpt_length( $length ) {
	return 16;
}
add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );

/*
 *  Credit: http://www.ronvangorp.com/how-to-change-wordpress-excerpt-ellipsis/
 */
function new_excerpt_more( $more ) {
	return '...';
}
add_filter('excerpt_more', 'new_excerpt_more');


/*
 * Credit: https://developer.wordpress.org/reference/functions/wp_nav_menu/
 */
function register_my_menus() {
  register_nav_menus(
    array(
		'top-level' => __( 'Main Menu' ),
		'bottom-level' => __( 'Secondary Menu' ),
     )
   );
}
add_action( 'init', 'register_my_menus', 'perseverance_comment' );

/*
 * Override default comments
 */
function bootstrap_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	if ( $comment->comment_approved == '1' ): ?>
    <li class="media">
        <?php echo get_avatar( $comment, $args['avatar_size'], '', '', array('class' => 'img-thumbnail mr-3')); ?>
        <div class="media-body">
            <h4 class="media-heading"><?php comment_author_link() ?></h4>
            <time><a href="#comment-<?php comment_ID() ?>" pubdate><?php comment_date() ?> at <?php comment_time() ?></a></time>
            <?php comment_text() ?>
        </div>
    </li>
    <?php endif;
}




/**
 * Register our sidebars and widgetized areas.
 *
 */
function perseverance_widgets_init() {
	  
	register_sidebar( array(
		'name'          => 'Sub Navigation Aside',
		'id'            => 'subnav_aside',
		'before_widget' => '<div>',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="h6">',
		'after_title'   => '</h2>',
  	) );
  
	register_sidebar( array(
		'name'          => 'Homepage Hero Aside',
		'id'            => 'homepage_hero_aside',
		'before_widget' => '<div class="card card-body bg-card-gradient shadow-sm my-3">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="card-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => 'Homepage Lower Main',
		'id'            => 'homepage_lower_main',
		'before_widget' => '<div class="card card-body bg-card-gradient shadow-sm my-3">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="card-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => 'Homepage Lower Aside',
		'id'            => 'homepage_lower_aside',
		'before_widget' => '<div class="card shadow-sm my-3">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="lower-aside-title">',
		'after_title'   => '</h2>',
	) );
  
	register_sidebar( array(
		'name'          => 'Content Aside',
		'id'            => 'content_aside',
		'before_widget' => '<div>',
		'after_widget'  => '</div><hr>',
		'before_title'  => '<h2 class="section-title h3">',
		'after_title'   => '</h2>',
	) );
  
	register_sidebar( array(
		'name'          => 'Content After',
		'id'            => 'content_after',
		'before_widget' => '<div class="content-after-widget">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="card-title h3">',
		'after_title'   => '</h2>',
	) );
  
	register_sidebar( array(
		'name'          => 'Footer Left',
		'id'            => 'footer_left',
		'before_widget' => '<div>',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="h4">',
		'after_title'   => '</h2>',
	) );
  
	register_sidebar( array(
		'name'          => 'Footer Mid Left',
		'id'            => 'footer_mid_left',
		'before_widget' => '<div>',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="h4">',
		'after_title'   => '</h2>',
	) );
  
	register_sidebar( array(
		'name'          => 'Footer Mid Right',
		'id'            => 'footer_mid_right',
		'before_widget' => '<div>',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="h4">',
		'after_title'   => '</h2>',
	) );
  
	register_sidebar( array(
		'name'          => 'Footer Right',
		'id'            => 'footer_right',
		'before_widget' => '<div>',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="h4">',
		'after_title'   => '</h2>',
	) );
  
	register_sidebar( array(
		'name'          => 'Footer Bottom',
		'id'            => 'footer_bottom',
		'before_widget' => '<div>',
		'after_widget'  => '</div>',
		'before_title'  => '<h2>',
		'after_title'   => '</h2>',
	) );

}

add_action( 'widgets_init', 'perseverance_widgets_init' );

require_once( 'includes/wp_scss_customizer.php' );
require_once( 'includes/wp_bootstrap_navwalker.php' );
?>