<?php

/**
 * The following is for the Perseverance theme
 */

function perseverance_customize_register( $wp_customize ) {

    // Customizer Settings and Controls for Theme

    $wp_customize->add_section( 'title_tagline' , array(
        'title'      => __( 'Site & Theme Settings', 'perseverance' ),
        'priority'   => 20,
    ));

    // add a setting for the site logo
    $wp_customize->add_setting('perseverance_theme_logo');
    // Add a control to upload the logo
    $wp_customize->add_control( new WP_Customize_Image_Control(
        $wp_customize, 'perseverance_theme_logo',
            array(
            'label'       => __( 'Upload Logo', 'perseverance' ),
            'description' => 'The logo will replace the text version of the site name. If you\'d prefer to use the text version or use a custom font awesome 5 icon instead, leave this blank.',
            'section'     => 'title_tagline',
            'settings'    => 'perseverance_theme_logo',
            'priority'    => 70
        )
    ));

    $wp_customize->add_setting( 'perseverance_theme_logo_width', array(
        'default' => 50,
    ) );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_theme_logo_width',
            array(
                'label'       => __( 'Image Logo Width', 'perseverance' ),
                'description' => 'Enter a number to choose a custom width for your image logo.',
                'section'     => 'title_tagline',
                'settings'    => 'perseverance_theme_logo_width',
                'type'        => 'number',
                'priority'    => 70
            )
        )
    );

    $wp_customize->add_setting( 'perseverance_theme_icon', array(
        'default'     => 'fab fa-wordpress',
    ));
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_theme_icon',
            array(
                'label'       => __( 'Font Awesome 5 Icon', 'perseverance' ),
                'description' => 'Use the appropriate classes for any Font Awesome 5 icon (eg: fab/fas fa-[icon]) and an icon will appear before the text version of your logo. For help see https://fontawesome.com',
                'section'     => 'title_tagline',
                'settings'    => 'perseverance_theme_icon',
                'priority'    => 70
            )
        )
    );

    $wp_customize->add_setting( 'perseverance_content_header',
        array( 'default' => 'bg-diag' )
    );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_content_header',
            array(
                'label'       => __( 'Header Pattern', 'perseverance' ),
                'description' => 'Choose the Background patern for taxonomy, posts, other pages.',
                'section'     => 'title_tagline',
                'settings'    => 'perseverance_content_header',
                'type'        => 'select',
                'choices' => array(
                    ''                        => __( 'None' ),
                    'bg-texture'              => __( 'Texture' ),
                    'bg-diag'                 => __( 'Thin Diagonal Stripes' ),
                    'bg-jigsaw'               => __( 'Jigsaw Puzzle' ),
                    'bg-hexagons'             => __( 'Hexagons' ),
                    'bg-overlapping-hexagons' => __( 'Overlapping Hexagons' ),
                    'bg-overlapping-diamonds' => __( 'Overlapping Diamonds' ),
                    'bg-flipped-diamonds'     => __( 'Flipped Diamonds' ),
                    'bg-autumn'               => __( 'Autumn' ),
                    'bg-jupiter'              => __( 'Jupiter' ),
                    'bg-piano'                => __( 'Piano Keys' ),
                    'bg-dominos'              => __( 'Dominos' ),
                    'bg-checkers'             => __( 'Checkers' ),
                    'bg-tiny-checkers'        => __( 'Tiny Checkers' ),
                    'bg-bubbles'              => __( 'Bubbles' ),
                    'bg-glamorous'            => __( 'Glamorous' ),
                    'bg-food'                 => __( 'Food' ),
                    'bg-temple'               => __( 'Temple' ),
                    'bg-circuit'              => __( 'Circuit Board' ),
                    'bg-stripes'              => __( 'Stripes' ),
                    'bg-polka-dots'           => __( 'Polka Dots' ),
                    'bg-four-point-stars'     => __( 'Four Point Stars' ),
                    'bg-formal-invitation'    => __( 'Formal Invitiation' ),
                    'bg-plus'                 => __( 'Plus' ),
                    'bg-rounded-plus'         => __( 'Rounded Plus' ),
                    'bg-random-shapes'        => __( 'Random Shapes' ),
                    'bg-wiggle'               => __( 'Wiggles' ),
                    'bg-lips'                 => __( 'Lips' ),
                    'bg-cage'                 => __( 'Cage' ),
                    'bg-moroccan'             => __( 'Moroccan' ),
                    'bg-bamboo'               => __( 'Bamboo' ),
                    'bg-morphing'             => __( 'Morphing' ),
                    'bg-brick-wall'           => __( 'Brick Wall' ),
                    'bg-banknote'             => __( 'Banknote' ),
                    'bg-boxes'                => __( 'Boxes' ),
                    'bg-squares-squared'      => __( 'Squares Squared' ),
                    'bg-rain'                 => __( 'Rain' ),
                    'bg-aztec'                => __( 'Aztec' ),
                    'bg-tic-tag-toe'          => __( 'Tic Tac Toe' ),
                    'bg-zig-zag'              => __( 'Zig Zag' ),
                    'bg-connections'          => __( 'Connections' ),
                    'bg-groovy'               => __( 'Groovy' ),
                    'bg-intersecting-circles' => __( 'Intersecting Circles' ),
                    'bg-signal'               => __( 'Signal' ),
                    'bg-wallpaper'            => __( 'Wallpaper' ),
                  ),
                'priority'     => 70
            )
        )
    );

    $wp_customize->add_setting( 'perseverance_header_padding',
        array( 'default' => '1rem' )
    );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_header_padding',
            array(
                'label'       => __( 'Page Header Spacing', 'perseverance' ),
                'description' => 'Choose the amount of padding you\'d like for page headings.',
                'section'     => 'title_tagline',
                'settings'    => 'perseverance_header_padding',
                'type'        => 'select',
                'choices' => array(
                    '0rem'    => __( 'None' ),
                    '1rem'    => __( 'Slim' ),
                    '2rem'    => __( 'Regular' ),
                    '3rem'    => __( 'Large' ),
                    '4rem'    => __( 'X-Large' ),
                    '5rem'    => __( 'Jumbotron' ),
                  ),
                'priority'    => 70
            )
        )
    );

    $wp_customize->add_setting( 'perseverance_theme_container', array(
        'default' => false,
    ) );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_theme_container',
            array(
                'label'       => __( 'Container Fluid', 'perseverance' ),
                'description' => 'Give the theme a fluid-width container.',
                'section'     => 'title_tagline',
                'settings'    => 'perseverance_theme_container',
                'type'        => 'checkbox',
                'priority'    => 70
            )
        )
    );

    $wp_customize->add_setting( 'perseverance_theme_subnav', array(
        'default' => false,
    ) );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_theme_subnav',
            array(
                'label'       => __( 'Hide Subnavigation', 'perseverance' ),
                'description' => 'Remove lower navigation bar.',
                'section'     => 'title_tagline',
                'settings'    => 'perseverance_theme_subnav',
                'type'        => 'checkbox',
                'priority'    => 70
            )
        )
    );

    $wp_customize->add_setting( 'perseverance_hide_header', array(
        'default' => false,
    ) );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_hide_header',
            array(
                'label'       => __( 'Hide Page Headers', 'perseverance' ),
                'description' => 'Remove page headers in order to implement your own.',
                'section'     => 'title_tagline',
                'settings'    => 'perseverance_hide_header',
                'type'        => 'checkbox',
                'priority'    => 70
            )
        )
    );

    $wp_customize->add_setting( 'perseverance_below_header_pad', array(
        'default' => false,
    ) );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_below_header_pad',
            array(
                'label'       => __( 'Remove Padding Below Headers', 'perseverance' ),
                'description' => 'Remove the Padding below a page header.',
                'section'     => 'title_tagline',
                'settings'    => 'perseverance_below_header_pad',
                'type'        => 'checkbox',
                'priority'    => 70
            )
        )
    );

    $wp_customize->add_setting( 'perseverance_theme_search', array(
        'default' => false,
    ) );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_theme_search',
            array(
                'label'       => __( 'Hide Default Search', 'perseverance' ),
                'description' => 'Remove search widgets from theme.',
                'section'     => 'title_tagline',
                'settings'    => 'perseverance_theme_search',
                'type'        => 'checkbox',
                'priority'    => 70
            )
        )
    );

    $wp_customize->add_setting( 'perseverance_theme_sidebar', array(
        'default' => false,
    ) );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_theme_sidebar',
            array(
                'label'       => __( 'Hide Content Aside', 'perseverance' ),
                'description' => 'Remove sidebar widget from theme.',
                'section'     => 'title_tagline',
                'settings'    => 'perseverance_theme_sidebar',
                'type'        => 'checkbox',
                'priority'    => 70
            )
        )
    );

    $wp_customize->add_setting( 'perseverance_theme_after', array(
        'default' => false,
    ) );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_theme_after',
            array(
                'label'       => __( 'Hide Content After', 'perseverance' ),
                'description' => 'Remove After Content widget from theme.',
                'section'     => 'title_tagline',
                'settings'    => 'perseverance_theme_after',
                'type'        => 'checkbox',
                'priority'    => 70
            )
        )
    );

    $wp_customize->add_setting( 'perseverance_theme_businessinfo', array(
        'default' => false,
    ) );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_theme_businessinfo',
            array(
                'label'       => __( 'Hide Business Info', 'perseverance' ),
                'description' => 'Remove Business Info from the footer. This component will auto-hide if occupied by a widget.',
                'section'     => 'title_tagline',
                'settings'    => 'perseverance_theme_businessinfo',
                'type'        => 'checkbox',
                'priority'    => 70
            )
        )
    );

    $wp_customize->add_setting( 'perseverance_footer_alignment',
        array( 'default' => 'justify-content-start' )
    );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_footer_alignment',
            array(
                'label'       => __( 'Footer Widget Vertical Alignment', 'perseverance' ),
                'description' => 'Choose the vertical alignment for you footer widgets. (May require multiple widgets per section for full effect.)',
                'section'     => 'title_tagline',
                'settings'    => 'perseverance_footer_alignment',
                'type'        => 'select',
                'choices' => array(
                    'justify-content-start'      => __( 'Justified Start' ),
                    'justify-content-center'    => __( 'Justified Center' ),
                    'justify-content-end'     => __( 'Justified End' ),
                    'justify-content-between' => __( 'Justified Between' ),
                    'justify-content-around' => __( 'Justified Around' ),
                  ),
                'priority'    => 70
            )
        )
    );

    $wp_customize->add_setting( 'perseverance_footer_text_1',
        array( 'default' => 'text-left' )
    );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_footer_text_1',
            array(
                'label'       => __( 'First Footer Widget Text', 'perseverance' ),
                'description' => 'Choose the text-align for your first footer widget.',
                'section'     => 'title_tagline',
                'settings'    => 'perseverance_footer_text_1',
                'type'        => 'select',
                'choices' => array(
                    'text-left'      => __( 'Text Left' ),
                    'text-center'    => __( 'Text Center' ),
                    'text-right'     => __( 'Text Right' ),
                    'text-justified' => __( 'Text Justified' ),
                  ),
                'priority'    => 70
            )
        )
    );

    $wp_customize->add_setting( 'perseverance_footer_text_2',
        array( 'default' => 'text-left' )
    );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_footer_text_2',
            array(
                'label'       => __( 'Second Footer Widget Text', 'perseverance' ),
                'description' => 'Choose the text-align for your second footer widget.',
                'section'     => 'title_tagline',
                'settings'    => 'perseverance_footer_text_2',
                'type'        => 'select',
                'choices' => array(
                    'text-left'      => __( 'Text Left' ),
                    'text-center'    => __( 'Text Center' ),
                    'text-right'     => __( 'Text Right' ),
                    'text-justified' => __( 'Text Justified' ),
                  ),
                'priority'    => 70
            )
        )
    );

    $wp_customize->add_setting( 'perseverance_footer_text_3',
        array( 'default' => 'text-left' )
    );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_footer_text_3',
            array(
                'label'       => __( 'Third Footer Widget Text', 'perseverance' ),
                'description' => 'Choose the text-align for your third footer widget.',
                'section'     => 'title_tagline',
                'settings'    => 'perseverance_footer_text_3',
                'type'        => 'select',
                'choices' => array(
                    'text-left'      => __( 'Text Left' ),
                    'text-center'    => __( 'Text Center' ),
                    'text-right'     => __( 'Text Right' ),
                    'text-justified' => __( 'Text Justified' ),
                  ),
                'priority'    => 70
            )
        )
    );

    $wp_customize->add_setting( 'perseverance_footer_text_4',
        array( 'default' => 'text-left' )
    );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_footer_text_4',
            array(
                'label'       => __( 'Fourth Footer Widget Text', 'perseverance' ),
                'description' => 'Choose the text-align for your fourth footer widget.',
                'section'     => 'title_tagline',
                'settings'    => 'perseverance_footer_text_4',
                'type'        => 'select',
                'choices' => array(
                    'text-left'      => __( 'Text Left' ),
                    'text-center'    => __( 'Text Center' ),
                    'text-right'     => __( 'Text Right' ),
                    'text-justified' => __( 'Text Justified' ),
                  ),
                'priority'    => 70
            )
        )
    );
    
    // Customizer Settings and Controls for Homepage

    $wp_customize->add_section( 'perseverance_homepage_section', array(
        'title'      => __( 'Homepage Information', 'perseverance' ),
        'priority'   => 30,
    ));

    $wp_customize->add_setting('perseverance_homepage_fold_img',
        array( 'default' => '/assets/images/dallas.jpg' )
    );
    $wp_customize->add_control( new WP_Customize_Image_Control(
        $wp_customize, 'perseverance_homepage_fold_img',
            array(
            'label'       => 'Header Background',
            'description' => 'Upload a background image for content above the fold.',
            'section'     => 'perseverance_homepage_section',
            'settings'    => 'perseverance_homepage_fold_img',
            'priority'    => 1
        )
    ));

    $wp_customize->add_setting(
        'perseverance_homepage_title',
        array( 'default' => 'Welcome!' )
    );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_homepage_title',
            array(
                'label'       => __( 'Main Title', 'perseverance' ),
                'description' => 'This will likely be the first thing visitors see. Make sure to be eye catching!',
                'section'     => 'perseverance_homepage_section',
                'settings'    => 'perseverance_homepage_title',
                'priority'    => 1
            )
        )
    );

    $wp_customize->add_setting(
        'perseverance_homepage_text',
        array( 'default' => 'This theme is designed for accessibility conscious websites. Presenting actionable goals above the fold, a section for featured content, testimonials & more. Use as is or make something unique easily with Bootstrap 4 classes.' )
    );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_homepage_text',
            array(
                'label'       => __( 'Main Intoduction', 'perseverance' ),
                'description' => 'Descriptive text for your website\'s introduction.',
                'section'     => 'perseverance_homepage_section',
                'settings'    => 'perseverance_homepage_text',
                'type'        => 'textarea',
                'priority'    => 1
            )
        )
    );

    $wp_customize->add_setting(
        'perseverance_homepage_featlength',
        array( 'default' => 0 )
    );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_homepage_featlength',
            array(
                'label'       => __( 'Number of Featured Posts', 'perseverance' ),
                'description' => 'Set the maximum number of featured posts to show on the homepage.',
                'section'     => 'perseverance_homepage_section',
                'settings'    => 'perseverance_homepage_featlength',
                'type'        => 'number',
                'priority'    => 1
            )
        )
    );

    $wp_customize->add_setting(
        'perseverance_homepage_featured',
        array( 'default' => 'uncategorized' )
    );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_homepage_featured',
            array(
                'label'       => __( 'Featured Post Category', 'perseverance' ),
                'description' => 'Default: uncategorized',
                'section'     => 'perseverance_homepage_section',
                'settings'    => 'perseverance_homepage_featured',
                'priority'    => 1
            )
        )
    );

    $wp_customize->add_setting('perseverance_homepage_lower_img',
        array( 'default' => '/assets/images/dallas2.jpg' )
    );
    $wp_customize->add_control( new WP_Customize_Image_Control(
        $wp_customize, 'perseverance_homepage_lower_img',
            array(
            'label'       => __( 'Lower Background Image', 'perseverance' ),
            'description' => 'Upload a background image for the bottom of the homepage.',
            'section'     => 'perseverance_homepage_section',
            'settings'    => 'perseverance_homepage_lower_img',
            'priority'    => 1
        )
    ));
	
    // Customizer Settings and Controls for company info
	
    $wp_customize->add_section( 'perseverance_company_section' , array(
        'title'      => __( 'Business Information', 'perseverance' ),
        'priority'   => 30,
    ));

    $wp_customize->add_setting( 'perseverance_company_tn',
        array( 'default' => '1 (555) 555-5555' )
    );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_company_tn',
            array(
                'label'       => __( 'Phone Number', 'perseverance' ),
                'description' => 'This will show at the top of the navigation and be clickable by your mobile users, please include area code and format as such "# (###) ###-####".',
                'section'     => 'perseverance_company_section',
                'settings'    => 'perseverance_company_tn',
                'priority'    => 1
            )
        )
    );

    $wp_customize->add_setting( 'perseverance_social_fb',
        array( 'default' => 'https://facebook.com/' )
    );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_social_fb',
            array(
                'label'      => __( 'Facebook', 'perseverance' ),
                'section'    => 'perseverance_company_section',
                'settings'   => 'perseverance_social_fb',
                'type'       => 'url',
                'priority'   => 1
            )
        )
    );

    $wp_customize->add_setting( 'perseverance_social_tw',
        array( 'default' => 'https://twitter.com/' )
    );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_social_tw',
            array(
                'label'      => __( 'Twitter', 'perseverance' ),
                'section'    => 'perseverance_company_section',
                'settings'   => 'perseverance_social_tw',
                'type'       => 'url',
                'priority'   => 1
            )
        )
    );

    $wp_customize->add_setting( 'perseverance_social_in', array());
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_social_in',
            array(
                'label'      => __( 'Instagram', 'perseverance' ),
                'section'    => 'perseverance_company_section',
                'settings'   => 'perseverance_social_in',
                'type'       => 'url',
                'priority'   => 1
            )
        )
    );

    $wp_customize->add_setting( 'perseverance_social_yt',
        array( 'default' => 'https://youtube.com/channel/' )
    );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_social_yt',
            array(
                'label'      => __( 'Youtube', 'perseverance' ),
                'section'    => 'perseverance_company_section',
                'settings'   => 'perseverance_social_yt',
                'type'       => 'url',
                'priority'   => 1
            )
        )
    );

    $wp_customize->add_setting( 'perseverance_social_li',
        array( 'default' => 'https://linkedin.com/in/' )
    );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_social_li',
            array(
                'label'      => __( 'Linkdein', 'perseverance' ),
                'section'    => 'perseverance_company_section',
                'settings'   => 'perseverance_social_li',
                'type'       => 'url',
                'priority'   => 1
            )
        )
    );

    $wp_customize->add_setting( 'perseverance_social_re', array());
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'perseverance_social_re',
            array(
                'label'      => __( 'Reddit', 'perseverance' ),
                'section'    => 'perseverance_company_section',
                'settings'   => 'perseverance_social_re',
                'type'       => 'url',
                'priority'   => 1
            )
        )
    );

}
add_action( 'customize_register', 'perseverance_customize_register' );
?>