<?php
/**
 * Requires the WP-SCSS plugin to be installed and activated.
 *
 * @package      Customizer Sass
 * @link         https://seothemes.net
 * @author       Seo Themes
 * @copyright    Copyright © 2017 Seo Themes
 * @license      GPL-2.0+
 */
include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

// Check if plugin is active
if ( !is_plugin_active( 'wp-scss/wp-scss.php' ) ) {
  return;
}
// Always recompile in the customizer
if ( is_customize_preview() && !defined('WP_SCSS_ALWAYS_RECOMPILE')) {
	define('WP_SCSS_ALWAYS_RECOMPILE', true);
}
// Update the default paths to match theme
$persevereance_wpscss_options = get_option('wpscss_options');
if( $persevereance_wpscss_options['scss_dir'] !== '/assets/scss/' || $persevereance_wpscss_options['css_dir'] !== '/assets/css/' ) {
	// Alter the options array appropriately
	$persevereance_wpscss_options['scss_dir'] = '/assets/scss/';
	$persevereance_wpscss_options['css_dir'] = '/assets/css/';
	// Update entire array
	update_option('wpscss_options', $persevereance_wpscss_options);
}
// Create array of default colors
$persevereance_defaults = array(
	'primary_color'   => '#274e71',
	'secondary_color' => '#908c88',
	'info_color'	  => '#6f42c1',
	'success_color'   => '#186429',
	'warning_color'   => '#BD7F1C',
	'danger_color'	  => '#7E3B38',
	'link_color'	  => '#274e71',
);
// Update SCSS variables
function wp_scss_set_variables() {
    
    // Get the default colors
    global $persevereance_defaults;
    // Prepare the array
    $variables = array();
    
    // Loop through each variable and get theme_mod
    foreach( $persevereance_defaults as $key => $value ) {
    	$variables[$key] = get_theme_mod( $key, $value );
    }
	return $variables;
    
}
add_filter('wp_scss_variables', 'wp_scss_set_variables'); 
// Register settings and controls with the Customizer.
add_action( 'customize_register', 'starter_customizer_register' );
function starter_customizer_register() {
	global $wp_customize;
	global $persevereance_defaults;
  
	// Loop through each variable in the array
	foreach($persevereance_defaults as $key => $value) {
			// Add setting for each variable
			$wp_customize->add_setting( $key , array(
				'default' => $value,
				'sanitize_callback' => 'sanitize_hex_color',
			) );
			
			// Add control for each variable
			$wp_customize->add_control(
				new WP_Customize_Color_Control( 
				$wp_customize, 
				$key, 
				array(
					'label'      => ucwords( str_replace( '_color', '', $key ) ) . ' Color',
					'section'     => 'title_tagline',
					'settings'   => $key,
				) ) 
			);
		
	}
}
?>